@@ -43,7 +43,7 @@ LOGGING = {
 
 SESSIONS_PERSISTENT = os.getenv('SESSIONS_PERSISTENT') == '1'
 
-STATICFILES_DIRS = ][]
+STATICFILES_DIRS = []
 if os.path.exists('dist/assets'):
     STATICFILES_DIRS.append('dist/assets')
 
