@@ -1,18 +1,26 @@
+"""Dynamically constructs a Django settings module based on the operating
+platform environment with consistent defaults.
+"""
+#pylint: disable=unused-wildcard-import,invalid-name,wildcard-import
+#pylint: disable=wrong-import-position,no-member
 import importlib
 import os
 import sys
 import inspect
 
-import yaml
-
 import unimatrix.const
 import unimatrix.lib.environ
 from unimatrix.ext.django.lib import etc
+from unimatrix.ext.django.settings.email import *
+from unimatrix.ext.django.settings.rdbms import DATABASES
+from unimatrix.ext.django.settings.http import *
 
 
 __all__ = []
 
-assert 'UNIMATRIX_SETTINGS_MODULE' in os.environ
+
+if 'UNIMATRIX_SETTINGS_MODULE' not in os.environ:
+    raise RuntimeError('Unable to load UNIMATRIX_SETTINGS_MODULE')
 
 
 # Retrieve the current module from the sys.modules dictionary;
@@ -24,7 +32,7 @@ base_settings = importlib.import_module(os.environ['UNIMATRIX_SETTINGS_MODULE'])
 # Iterate over all attributes in the original settings module
 # and set them as attributes.
 for attname, value in inspect.getmembers(base_settings):
-    if attname == 'INSTALLED_APPS':
+    if attname == 'INSTALLED_APPS' and 'unimatrix.ext.django' not in value:
         value = tuple(['unimatrix.ext.django'] + list(value))
     setattr(self, attname, value)
 
@@ -38,38 +46,18 @@ from unimatrix.ext.django.settings.const import *
 # by the Unimatrix platform. Since they are mandatory for deployment,
 # we have the assignments raise an exception if the keys do
 # not exist.
-ALLOWED_HOSTS = unimatrix.lib.environ.parselist(os.environ,
-    'HTTP_ALLOWED_HOSTS', sep=';')
-
 API_BROWSER_ENABLED = os.getenv('API_BROWSER_ENABLED') == '1'
 
 API_BROWSER_PATH = os.getenv('API_BROWSER_PATH') or 'browse/'
 
-CSRF_COOKIE_DOMAIN = os.getenv('CSRF_COOKIE_DOMAIN')
-
-CSRF_COOKIE_SECURE = True
-
 DEBUG = os.getenv('DEBUG') == '1'
 
-DATABASES = etc.load_databases(
-    os.path.join(unimatrix.const.SECDIR, 'rdbms', 'connections'))
-
 DEPLOYMENT_ENV = os.getenv('DEPLOYMENT_ENV') or 'testing'
 
 ROOT_URLCONF = 'unimatrix.ext.django.urls.runtime'
 
 SECRET_KEY = os.getenv('SECRET_KEY') or ('0' * 64)
 
-SECURE_HSTS_SECONDS = 86400 * 365
-
-SECURE_HSTS_PRELOAD = True
-
-SESSION_COOKIE_DOMAIN = os.getenv('SESSION_COOKIE_DOMAIN')
-
-SESSION_COOKIE_SECURE = True
-
-SESSION_COOKIE_HTTPONLY = True
-
 SESSION_ENGINE = 'django.contrib.sessions.backends.cache'
 if os.getenv('SESSIONS_PERSISTENT') == '1':
     raise NotImplementedError
